@@ -295,9 +295,8 @@ class Sheet:
         if isinstance(row, int):
             row = self.data_rows[row]
 
-        c: Cell
         for c in row:
-            c.style = style
+            row[c].style = style
 
     def remove_row(self, row: dict) -> None:
         self.data_rows.remove(row)
